@@ -1,6 +1,7 @@
 from gettext import gettext
 from typing import (
     TYPE_CHECKING,
+    Callable,
     Dict,
     List,
     Optional,
@@ -20,7 +21,7 @@ if TYPE_CHECKING:
 
 
 @attr.s
-class AssertionResult(object):
+class AssertionResult:
     snapshot_location: str = attr.ib()
     snapshot_name: str = attr.ib()
     asserted_data: Optional["SerializedData"] = attr.ib()
@@ -43,20 +44,23 @@ class SnapshotAssertion:
     _extension_class: Type["AbstractSyrupyExtension"] = attr.ib(kw_only=True)
     _test_location: "TestLocation" = attr.ib(kw_only=True)
     _update_snapshots: bool = attr.ib(kw_only=True)
-    _executions: int = attr.ib(init=False, default=0, kw_only=True)
-    _execution_results: Dict[int, "AssertionResult"] = attr.ib(
-        init=False, factory=dict, kw_only=True
-    )
+    _extension: Optional["AbstractSyrupyExtension"] = attr.ib(init=False, default=None)
+    _executions: int = attr.ib(init=False, default=0)
+    _execution_results: Dict[int, "AssertionResult"] = attr.ib(init=False, factory=dict)
+    _post_assert_actions: List[Callable[..., None]] = attr.ib(init=False, factory=list)
 
     def __attrs_post_init__(self) -> None:
         self._session.register_request(self)
 
+    def __init_extension(
+        self, extension_class: Type["AbstractSyrupyExtension"]
+    ) -> "AbstractSyrupyExtension":
+        return extension_class(test_location=self._test_location)
+
     @property
     def extension(self) -> "AbstractSyrupyExtension":
-        if not getattr(self, "_extension", None):
-            self._extension: "AbstractSyrupyExtension" = self._extension_class(
-                test_location=self._test_location
-            )
+        if not self._extension:
+            self._extension = self.__init_extension(self._extension_class)
         return self._extension
 
     @property
@@ -68,8 +72,12 @@ class SnapshotAssertion:
         return self._execution_results
 
     def use_extension(
-        self, extension_class: Optional[Type["AbstractSyrupyExtension"]] = None,
+        self, extension_class: Optional[Type["AbstractSyrupyExtension"]] = None
     ) -> "SnapshotAssertion":
+        """
+        Creates a new snapshot assertion fixture with the same options but using
+        specified extension class. This does not preserve assertion index or state.
+        """
         return self.__class__(
             update_snapshots=self._update_snapshots,
             test_location=self._test_location,
@@ -84,14 +92,28 @@ class SnapshotAssertion:
         assertion_result = self._execution_results[self.num_executions - 1]
         snapshot_data = assertion_result.recalled_data
         serialized_data = self.extension.serialize(data)
-        if snapshot_data is None:
-            return [gettext("Snapshot does not exist!")]
-
         diff: List[str] = []
+        if snapshot_data is None:
+            diff.append(gettext("Snapshot does not exist!"))
         if not assertion_result.success:
-            diff.extend(self.extension.diff_lines(serialized_data, snapshot_data))
+            diff.extend(self.extension.diff_lines(serialized_data, snapshot_data or ""))
         return diff
 
+    def __call__(
+        self, *, extension_class: Optional[Type["AbstractSyrupyExtension"]]
+    ) -> "SnapshotAssertion":
+        """
+        Modifies assertion instance options
+        """
+        if extension_class:
+            self._extension = self.__init_extension(extension_class)
+
+            def clear_extension() -> None:
+                self._extension = None
+
+            self._post_assert_actions.append(clear_extension)
+        return self
+
     def __repr__(self) -> str:
         attrs_to_repr = ["name", "num_executions"]
         attrs_repr = ", ".join(f"{a}={repr(getattr(self, a))}" for a in attrs_to_repr)
@@ -131,6 +153,14 @@ class SnapshotAssertion:
                 updated=snapshot_updated,
             )
             self._executions += 1
+            self._post_assert()
+
+    def _post_assert(self) -> None:
+        """
+        Restores assertion instance options
+        """
+        while self._post_assert_actions:
+            self._post_assert_actions.pop()()
 
     def _recall_data(self, index: int) -> Optional["SerializableData"]:
         try:
