@@ -3,3 +3,7 @@ SNAPSHOT_EMPTY_FOSSIL_KEY = "empty snapshot fossil"
 SNAPSHOT_UNKNOWN_FOSSIL_KEY = "unknown snapshot fossil"
 
 EXIT_STATUS_FAIL_UNUSED = 1
+
+SYMBOL_ELLIPSIS = "..."  # U+2026
+SYMBOL_NEW_LINE = "␤"  # U+2424
+SYMBOL_CARRIAGE = "␍"  # U+240D
