@@ -1,4 +1,4 @@
-import os
+from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -8,6 +8,8 @@ from typing import (
     Set,
 )
 
+import attr
+
 from .constants import EXIT_STATUS_FAIL_UNUSED
 from .data import SnapshotFossils
 from .report import SnapshotReport
@@ -18,18 +20,18 @@ if TYPE_CHECKING:
     from .extensions.base import AbstractSyrupyExtension  # noqa: F401
 
 
+@attr.s
 class SnapshotSession:
-    def __init__(
-        self, *, warn_unused_snapshots: bool, update_snapshots: bool, base_dir: str
-    ):
-        self.warn_unused_snapshots = warn_unused_snapshots
-        self.update_snapshots = update_snapshots
-        self.base_dir = base_dir
-        self.report: Optional["SnapshotReport"] = None
-        self._all_items: Set[Any] = set()
-        self._ran_items: Set[Any] = set()
-        self._assertions: List["SnapshotAssertion"] = []
-        self._extensions: Dict[str, "AbstractSyrupyExtension"] = {}
+    base_dir: str = attr.ib()
+    update_snapshots: bool = attr.ib()
+    warn_unused_snapshots: bool = attr.ib()
+    is_providing_paths: bool = attr.ib()
+    is_providing_nodes: bool = attr.ib()
+    report: Optional["SnapshotReport"] = attr.ib(default=None)
+    _all_items: Set[Any] = attr.ib(factory=set)
+    _ran_items: Set[Any] = attr.ib(factory=set)
+    _assertions: List["SnapshotAssertion"] = attr.ib(factory=list)
+    _extensions: Dict[str, "AbstractSyrupyExtension"] = attr.ib(factory=dict)
 
     def start(self) -> None:
         self.report = None
@@ -47,6 +49,8 @@ class SnapshotSession:
             assertions=self._assertions,
             update_snapshots=self.update_snapshots,
             warn_unused_snapshots=self.warn_unused_snapshots,
+            is_providing_paths=self.is_providing_paths,
+            is_providing_nodes=self.is_providing_nodes,
         )
         if self.report.num_unused:
             if self.update_snapshots:
@@ -74,6 +78,7 @@ class SnapshotSession:
     ) -> None:
         for unused_snapshot_fossil in unused_snapshot_fossils:
             snapshot_location = unused_snapshot_fossil.location
+
             extension = self._extensions.get(snapshot_location)
             if extension:
                 extension.delete_snapshots(
@@ -83,4 +88,4 @@ class SnapshotSession:
                     },
                 )
             elif snapshot_location not in used_snapshot_fossils:
-                os.remove(snapshot_location)
+                Path(snapshot_location).unlink()
