@@ -23,14 +23,6 @@ def bold(text: Union[str, int]) -> str:
     return colored.stylize(text, colored.attr("bold"))
 
 
-def mute(text: Union[str, int]) -> str:
-    return colored.stylize(text, colored.attr("dim"))
-
-
-def emphasize(text: Union[str, int]) -> str:
-    return colored.stylize(bold(text), colored.attr("underlined"))
-
-
 def error_style(text: Union[str, int]) -> str:
     return bold(red(text))
 
@@ -41,3 +33,23 @@ def warning_style(text: Union[str, int]) -> str:
 
 def success_style(text: Union[str, int]) -> str:
     return bold(green(text))
+
+
+def snapshot_style(text: Union[str, int]) -> str:
+    return colored.stylize(text, colored.bg(225) + colored.fg(90))
+
+
+def snapshot_diff_style(text: Union[str, int]) -> str:
+    return colored.stylize(text, colored.bg(90) + colored.fg(225))
+
+
+def received_style(text: Union[str, int]) -> str:
+    return colored.stylize(text, colored.bg(195) + colored.fg(23))
+
+
+def received_diff_style(text: Union[str, int]) -> str:
+    return colored.stylize(text, colored.bg(23) + colored.fg(195))
+
+
+def context_style(text: Union[str, int]) -> str:
+    return colored.stylize(text, colored.attr("dim"))
